unit UIPTVPage;

interface

uses
  Classes, SysUtils, FileUtil, UWebPage, UHTTPServer, UModuleUser,
  Generics.Collections;

type
  TChannelGroup = (cpBasic, cpStandard, cpMax, cpFilm, cpSuperBox, cpDokument,
    cpLaska, cpZpravodaj, cpDetske, cpSport, cpLeoTv, cpCesky);
  TChannelGroups = set of TChannelGroup;

  TChannel = class
    Name: string;
    Groups: TChannelGroups;
  end;

  { TChannels }

  TChannels = class(TObjectList<TChannel>)
    function AddNew(Name: string; Groups: TChannelGroups): TChannel;
    function GetNamesByGroup(Group: TChannelGroup): string;
    function GetCountByGroup(Group: TChannelGroup): Integer;
  end;

  { TIPTVPage }

  TIPTVPage = class(TWebPage)
    procedure DataModuleProduce(HandlerData: THTTPHandlerData);
  private
    function Row(Cells: array of string): string;
  public
    ModuleUser: TModuleUser;
  end;

var
  IPTVPage: TIPTVPage;


implementation

{$R *.lfm}

uses
  UCore, UHtmlClasses, UWebSession;

{ TChannels }

function TChannels.AddNew(Name: string; Groups: TChannelGroups): TChannel;
begin
  Result := TChannel.Create;
  Result.Name := Name;
  Result.Groups := Groups;
  Add(Result);
end;

function TChannels.GetNamesByGroup(Group: TChannelGroup): string;
var
  I: Integer;
begin
  Result := '';
  for I := 0 to Count - 1 do begin
    if Group in Items[I].Groups then begin
      if Result <> '' then Result := Result + ', ';
      Result := Result + Items[I].Name;
    end;
  end;
end;

function TChannels.GetCountByGroup(Group: TChannelGroup): Integer;
var
  I: Integer;
begin
  Result := 0;
  for I := 0 to Count - 1 do begin
    if Group in Items[I].Groups then begin
      Inc(Result);
    end;
  end;
end;

{ TIPTVPage }

procedure TIPTVPage.DataModuleProduce(HandlerData: THTTPHandlerData);
var
  Channels: TChannels;
begin
  with TWebSession(HandlerData) do begin
    if Request.Path.Count > 1 then begin
      PageNotFound;
      Exit;
    end;

    ModuleUser.LoadUserInfo;
    with HtmlDocument.Body, SubItems.AddString do begin
      Channels := TChannels.Create;
      with Channels do begin
        AddNew('360TuneBox', [cpMax]);
        AddNew('A11', [cpStandard, cpMax]);
        AddNew('AMC HD', [cpStandard, cpMax]);
        AddNew('Animal Planet HD', [cpStandard, cpMax, cpDokument]);
        AddNew('Arena Sport 1 HD', [cpStandard, cpMax, cpSport]);
        AddNew('Arena Sport 2 HD', [cpStandard, cpMax, cpSport]);
        AddNew('ATV', [cpBasic, cpStandard, cpMax]);
        AddNew('AXN', [cpStandard, cpMax, cpFilm]);
        AddNew('AXN Black', [cpStandard, cpMax, cpFilm]);
        AddNew('AXN White', [cpStandard, cpMax, cpFilm]);
        AddNew('Baby TV', [cpStandard, cpMax, cpDetske]);
        AddNew('BBC News', [cpMax, cpZpravodaj]);
        AddNew('Brazzers TV Europe', [cpStandard, cpMax, cpLaska]);
        AddNew('CNN', [cpStandard, cpMax]);
        AddNew('CNN Prima News HD', [cpBasic, cpStandard, cpMax]);
        AddNew('CS film/CS Horor', [cpStandard, cpMax, cpCesky]);
        AddNew('CS History', [cpBasic, cpStandard, cpMax, cpCesky]);
        AddNew('CS Mystery', [cpStandard, cpMax, cpCesky]);
        AddNew('ČT :D HD/ Art HD', [cpBasic, cpStandard, cpMax]);
        AddNew('ČT 1 HD', [cpBasic, cpStandard, cpMax]);
        AddNew('ČT 1 JM HD', [cpBasic, cpStandard, cpMax]);
        AddNew('ČT 1 JMC HD', [cpBasic, cpStandard, cpMax]);
        AddNew('ČT 1 SM HD', [cpBasic, cpStandard, cpMax]);
        AddNew('ČT 1 SMX HD', [cpBasic, cpStandard, cpMax]);
        AddNew('ČT 2 HD', [cpBasic, cpStandard, cpMax]);
        AddNew('ČT 3 HD', [cpBasic, cpStandard, cpMax]);
        AddNew('ČT 24 HD', [cpBasic, cpStandard, cpMax]);
        AddNew('ČT Sport HD', [cpBasic, cpStandard, cpMax]);
        AddNew('Desire TV HD', [cpStandard, cpMax]);
        AddNew('Discovery Channel HD', [cpStandard, cpMax, cpDokument]);
        AddNew('Discovery Science HD', [cpMax, cpDokument]);
        AddNew('Disney Channel', [cpStandard, cpMax, cpDetske]);
        AddNew('Disney junior', [cpStandard, cpMax, cpDetske]);
        AddNew('DocuBox HD', [cpMax]);
        AddNew('DTX HD', [cpMax, cpDokument]);
        AddNew('Dvojka HD', [cpBasic, cpStandard, cpMax]);
        AddNew('DW TV HD', [cpStandard, cpMax, cpZpravodaj]);
        AddNew('EroX HD', [cpMax, cpSuperBox, cpLaska]);
        AddNew('EroXXX HD', [cpMax, cpSuperBox, cpLaska]);
        AddNew('Euronews', [cpMax, cpZpravodaj]);
        AddNew('Eurosport 1 HD', [cpStandard, cpMax, cpSport]);
        AddNew('Eurosport 2 HD', [cpStandard, cpMax, cpSport]);
        AddNew('Extasy TV HD', [cpLeoTv]);
        AddNew('Fashion TV HD', [cpStandard, cpMax, cpZpravodaj]);
        AddNew('FashionBox HD', [cpMax, cpSuperBox]);
        AddNew('Fast&FunBox HD', [cpMax]);
        AddNew('FightBox HD', [cpMax, cpSuperBox]);
        AddNew('Film Europe HD', [cpStandard, cpMax, cpFilm]);
        AddNew('Film Europe + HD', [cpMax, cpFilm, cpCesky]);
        AddNew('Filmbox HD', [cpStandard, cpMax, cpSuperBox]);
        AddNew('Filmbox Extra HD', [cpMax, cpSuperBox]);
        AddNew('Filmbox Family', [cpMax, cpSuperBox]);
        AddNew('Filmbox Stars HD', [cpMax, cpSuperBox]);
        AddNew('Filmbox Premium HD', [cpMax, cpSuperBox]);
        AddNew('Fishing & Hunting', [cpStandard, cpMax, cpDokument]);
        AddNew('France 24 ENG', [cpMax, cpZpravodaj]);
        AddNew('Golf Channel HD', [cpMax, cpSport]);
        AddNew('Hobby TV HD', [cpBasic, cpStandard, cpMax]);
        AddNew('iConcerts', [cpStandard, cpMax]);
        AddNew('ID HD', [cpMax, cpDokument]);
        AddNew('Jednotka HD', [cpBasic, cpStandard, cpMax]);
        AddNew('Jihočeská televize', [cpBasic, cpStandard, cpMax]);
        AddNew('JOJ Family HD', [cpBasic, cpStandard, cpMax]);
        AddNew('JOJ Cinema HD', [cpStandard, cpMax, cpFilm]);
        AddNew('Leo TV HD', [cpBasic, cpStandard, cpMax, cpLeoTv]);
        AddNew('Leo TV GOLD HD', [cpLeoTv]);
        AddNew('Markíza International HD', [cpStandard, cpMax]);
        AddNew('Mezzo HD', [cpStandard, cpMax]);
        AddNew('Minimax', [cpStandard, cpMax]);
        AddNew('Mňam TV', [cpBasic, cpStandard, cpMax]);
        AddNew('Mňau TV HD', [cpBasic, cpStandard, cpMax]);
        AddNew('NASA TV HD', [cpBasic, cpStandard, cpMax]);
        AddNew('National Geographic HD', [cpMax, cpDokument]);
        AddNew('National Geographic Wild HD', [cpStandard, cpMax, cpDokument]);
        AddNew('Nickelodeon', [cpStandard, cpMax, cpDetske]);
        AddNew('Nickelodeon Jr.', [cpStandard, cpMax, cpDetske]);
        AddNew('Nick. Ukraine Pluto TV', [cpStandard, cpMax, cpDetske]);
        AddNew('Nova HD', [cpBasic, cpStandard, cpMax]);
        AddNew('Nova Action HD', [cpBasic, cpStandard, cpMax]);
        AddNew('Nova Cinema HD', [cpBasic, cpStandard, cpMax]);
        AddNew('Nova Gold HD', [cpBasic, cpStandard, cpMax]);
        AddNew('Nova Fun HD', [cpBasic, cpStandard, cpMax]);
        AddNew('Nova Lady HD', [cpBasic, cpStandard, cpMax]);
        AddNew('Nova Sport 1 HD', [cpMax, cpSport]);
        AddNew('Nova Sport 2 HD', [cpStandard, cpMax, cpSport]);
        AddNew('Óčko', [cpBasic, cpStandard, cpMax]);
        AddNew('Óčko Star', [cpBasic, cpStandard, cpMax]);
        AddNew('ORF1', [cpBasic, cpStandard, cpMax]);
        AddNew('ORF2', [cpBasic, cpStandard, cpMax]);
        AddNew('Paramount Network', [cpBasic, cpStandard, cpMax]);
        AddNew('PassionXXX HD', [cpLeoTv]);
        AddNew('Polar', [cpBasic, cpStandard, cpMax]);
        AddNew('Polsat', [cpBasic, cpStandard, cpMax]);
        AddNew('Praha TV', [cpBasic, cpStandard, cpMax]);
        AddNew('Prima COOL HD', [cpBasic, cpStandard, cpMax]);
        AddNew('Prima HD', [cpBasic, cpStandard, cpMax]);
        AddNew('Prima Krimi HD', [cpBasic, cpStandard, cpMax]);
        AddNew('Prima LOVE HD', [cpBasic, cpStandard, cpMax]);
        AddNew('Prima MAX HD', [cpBasic, cpStandard, cpMax]);
        AddNew('Prima Plus HD', [cpMax]);
        AddNew('Prima Show HD', [cpBasic, cpStandard, cpMax]);
        AddNew('Prima Star HD', [cpBasic, cpStandard, cpMax]);
        AddNew('Prima ZOOM HD', [cpBasic, cpStandard, cpMax]);
        AddNew('Reality Kings TV', [cpMax, cpLaska]);
        AddNew('Regionální Televize TVS HD', [cpBasic, cpStandard, cpMax]);
        AddNew('Relax', [cpBasic, cpStandard, cpMax]);
        AddNew('Retro Music Television', [cpBasic, cpStandard, cpMax]);
        AddNew('RTVS 24 HD', [cpBasic, cpStandard, cpMax]);
        AddNew('RTVS Šport HD', [cpBasic, cpStandard, cpMax]);
        AddNew('Seznam.cz TV HD', [cpBasic, cpStandard, cpMax]);
        AddNew('Šlágr Muzika TV', [cpMax]);
        AddNew('Šlágr Originál TV', [cpBasic, cpStandard, cpMax]);
        AddNew('Spark TV HD', [cpStandard, cpMax]);
        AddNew('Spektrum HD', [cpStandard, cpMax]);
        AddNew('Spektrum Home HD', [cpBasic, cpStandard, cpMax]);
        AddNew('Sport 1 HD', [cpStandard, cpMax]);
        AddNew('Sport 5 HD', [cpMax, cpSport]);
        AddNew('Sport 2 HD', [cpStandard, cpMax]);
        AddNew('Super Polsat', [cpBasic, cpStandard, cpMax]);
        AddNew('TA 3 HD', [cpBasic, cpStandard, cpMax]);
        AddNew('TLC HD', [cpStandard, cpMax, cpDokument]);
        AddNew('Travel Channel HD', [cpStandard, cpMax, cpDokument]);
        AddNew('Travelxp HD', [cpStandard, cpMax, cpDokument]);
        AddNew('Turbo TV HD', [cpStandard, cpMax, cpBasic]);
        AddNew('TV Brno 1', [cpBasic, cpStandard, cpMax]);
        AddNew('TV Lux', [cpBasic, cpStandard, cpMax]);
        AddNew('TV Noe', [cpBasic, cpStandard, cpMax]);
        AddNew('TV Puls', [cpBasic, cpStandard, cpMax]);
        AddNew('TV Puls 2', [cpBasic, cpStandard, cpMax]);
        AddNew('TV Rebel', [cpBasic, cpStandard, cpMax]);
        AddNew('TV5 Monde', [cpMax, cpZpravodaj]);
        AddNew('TVN', [cpBasic, cpStandard, cpMax]);
        AddNew('TVN 7', [cpBasic, cpStandard, cpMax]);
        AddNew('TVP Historia', [cpBasic, cpStandard, cpMax]);
        AddNew('TVP 3 Katowice', [cpBasic, cpStandard, cpMax]);
        AddNew('TVP Sport', [cpBasic, cpStandard, cpMax]);
        AddNew('TVP1 HD', [cpBasic, cpStandard, cpMax]);
        AddNew('TVP2 HD', [cpBasic, cpStandard, cpMax]);
        AddNew('UA:Pershyi', [cpBasic, cpStandard, cpMax]);
        AddNew('V1', [cpBasic, cpStandard, cpMax]);
        AddNew('Viasat Explore HD', [cpStandard, cpMax, cpDokument]);
        AddNew('Viasat History HD', [cpStandard, cpMax, cpDokument]);
        AddNew('Viasat Nature HD', [cpStandard, cpMax, cpDokument]);
        AddNew('ZAK TV', [cpBasic, cpStandard, cpMax]);
        AddNew('ZDF', [cpBasic, cpStandard, cpMax]);
      end;

      Text := Text + '<h3>Výhody</h3>' +
      '<ul>' +
      '<li>velké množství televizních kanálů za nízkou cenu</li>' +
      '<li>možnost si aktivovat službu a měnit balíčky po měsících bez několikaleté výpovědní lhůty</li>' +
      '<li>zpětné přehrávání 7 dní nazpět (timeshift)</li>' +
      '<li>možnost pozastavení přehrávání vysílání</li>' +
      '<li>možnost záznamu pořadů</li>' +
      '<li>televizi lze sledovat přes set-top box, Smart TV Samsung, LG a Android, tablet, smartphone nebo internetový prohlížeč</li>' +
      '<li>lze spárovat až 4 zařízení na jeden účet</li>' +
      '<li>vyzkoušení na měsíc zdarma</li>' +
      '<li>převzaté vysílání zajišťuje společnost <a href="https://www.4net.tv">4NET.TV services s.r.o.</a></li>' +
      '<li>pro provoz služby stačí i nejnižší internetový tarif Internet 20M za 190 Kč/měsíc</li>' +
      '</ul><br/>' +

      '<h3>Základní balíčky</h3>' +
      '<table class="WideTable"><tr><th>Balíček</th><th>Cena [Kč/měsíc]</th><th>Počet kanálů</th><th>Kanály</th></tr>' +
      Row(['Basic', '144', IntToStr(Channels.GetCountByGroup(cpBasic)), Channels.GetNamesByGroup(cpBasic)]) +
      Row(['Basic + tématika', '157', IntToStr(Channels.GetCountByGroup(cpBasic)), Channels.GetNamesByGroup(cpBasic)]) +
      Row(['Standard', '460', IntToStr(Channels.GetCountByGroup(cpStandard)), Channels.GetNamesByGroup(cpStandard)]) +
      Row(['Max', '624', IntToStr(Channels.GetCountByGroup(cpMax)), Channels.GetNamesByGroup(cpMax)]) +
      '</table>' +
      'Balíček Basic obsahuje stejné kanály jako Basic + tématika. Pro možnost volby tématických balíčků je ale nutné mít balíček Basic + tématika.<br/>' +

      '<h3>Tématické balíčky</h3>' +
      '<table class="WideTable"><tr><th>Balíček</th><th>Cena [Kč/měsíc]</th><th>Počet kanálů</th><th>Kanály</th></tr>' +
      Row(['Film', '53', IntToStr(Channels.GetCountByGroup(cpFilm)), Channels.GetNamesByGroup(cpFilm)]) +
      Row(['Superbox', '158', IntToStr(Channels.GetCountByGroup(cpSuperBox)), Channels.GetNamesByGroup(cpSuperBox)]) +
      Row(['Sport', '146', IntToStr(Channels.GetCountByGroup(cpSport)), Channels.GetNamesByGroup(cpSport)]) +
      Row(['Dětské', '40', IntToStr(Channels.GetCountByGroup(cpDetske)), Channels.GetNamesByGroup(cpDetske)]) +
      Row(['Česky', '45', IntToStr(Channels.GetCountByGroup(cpCesky)), Channels.GetNamesByGroup(cpCesky)]) +
      Row(['Láska', '60', IntToStr(Channels.GetCountByGroup(cpLaska)), Channels.GetNamesByGroup(cpLaska)]) +
      Row(['Zpravodaj', '19', IntToStr(Channels.GetCountByGroup(cpZpravodaj)), Channels.GetNamesByGroup(cpZpravodaj)]) +
      Row(['Dokument', '136', IntToStr(Channels.GetCountByGroup(cpDokument)), Channels.GetNamesByGroup(cpDokument)]) +
      Row(['Leo TV', '49', IntToStr(Channels.GetCountByGroup(cpLeoTv)), Channels.GetNamesByGroup(cpLeoTv)]) +
      '</table>' +
      'Celková cena vznikne jako součet zvolených tématických balíčků a základního balíčku Basic + tématika.<br/>' +

      //'<h3>Programová nabídka</h3>' +
      //'<table class="WideTable"><tr><th>Kanál</th><th>Basic</th><th>Basic+</th><th>Standard</th><th>Maxi</th><th>Second screen</th><th>PVR</th></tr>';

      //Text := Text + '</table>Second Screen - možnost přehrávat v internetovém prohlížeči, tabletu, smartphone či Smart TV.</br/>' +
      //'PVR - možnost záznamu pořadu na 1 měsíc.</br/>' +
      '<h3>Zřízení služby</h3>' +
      'Instalace a aktivace: zdarma<br/>' +
      'Cena set-top boxu: 2000 Kč<br/>' +
      'Webové rozhraní pro TV: <a href="https://live.4network.tv/">live.4network.tv</a><br/>' +
      'Návod ke služby 4network.tv: <a href="/docs/navod_4network.tv.pdf">navod_4network.tv.pdf</a><br/>' +
      '<br/>' +
      'Ceny uvedeny včetně DPH platné od 1.1.2024.';
      Channels.Free;
    end;
    GeneratePage(Self);
  end;
end;

function TIPTVPage.Row(Cells: array of string): string;
var
  I: Integer;
begin
  Result := '';
  for I := 0 to Length(Cells) - 1 do
    Result := Result + '<td>' + Cells[I] + '</td>';
  Result := '<tr>' + Result + '</tr>';
end;

end.

